![Test and Coverage Measuring](https://github.com/tarc/asyncfileserver/workflows/Test%20and%20Coverage%20Measuring/badge.svg?branch=develop) [![codecov](https://codecov.io/gh/tarc/asyncfileserver/branch/develop/graph/badge.svg)](https://codecov.io/gh/tarc/asyncfileserver)

# Simple File Server Featuring Python Async Constructs

This is a toy project to excercise the new async facilities from python 3.5+.
